@@ -83,7 +83,7 @@ Custom palettes should contain 64 8-bit-per-color-component RGB triplets.
  <tr><td>12</td><td>??</td><td>Dragon Ball Z 5 ("bootleg" original)</td></tr>
  <tr><td>13</td><td>CPROM</td><td>Videomation</td></tr>
  <tr><td>15</td><td>Multi-cart(bootleg)</td><td>100-in-1: Contra Function 16</td></tr>
- <tr><td>16</td><td>Bandai ??</td><td>Dragon Ball Z, SD Gundam Gaiden **EEPROM is not emulated</td></tr>
+ <tr><td>16</td><td>Bandai ??(X24C02P EEPROM)</td><td>Dragon Ball Z 3</td></tr>
  <tr><td>17</td><td>FFE F8 Series(hacked, bootleg)</td><td></td></tr>
  <tr><td>18</td><td>Jaleco SS806</td><td>Pizza Pop, Plasma Ball</td></tr>
  <tr><td>19</td><td>Namco 106</td><td>Splatter House, Mappy Kids</td></tr>
@@ -163,6 +163,7 @@ Custom palettes should contain 64 8-bit-per-color-component RGB triplets.
  <tr><td>156</td><td>??</td><td>Buzz and Waldog</td></tr>
  <tr><td>157</td><td>Bandai Datach ??</td><td>Datach DBZ, Datach SD Gundam Wars, **EEPROM is not emulated</td></tr>
  <tr><td>158</td><td nowrap>RAMBO 1 Derivative</td><td>Alien Syndrome</td></tr>
+ <tr><td>159</td><td>Bandai ??(X24C01P EEPROM)</td><td>Magical Taruruuto-kun</td></tr>
  <tr><td>160</td><td>(same as mapper 90)</td><td>(same as mapper 90)</td></tr>
  <tr><td>180</td><td>??</td><td>Crazy Climber</td></tr>
  <tr><td>182</td><td>??</td><td>Super Donkey Kong</td></tr>
@@ -491,5 +492,30 @@ necessarily 100% accurate or complete):
 
 <?php PrintSettings(); ?>
 
+ <?php BeginSection("Credits"); ?>
+ <p>
+  (This section is woefully outdated, being mostly copied from FCE Ultra)
+ <table border width="100%">
+  <tr><th>Name:</th><th>Contribution(s):</th></tr>
+  <tr><td>\Firebug\</td><td>High-level mapper information.</td></tr>
+  <tr><td>Bero</td><td>Original FCE source code.</td></tr>
+  <tr><td>Brad Taylor</td><td>NES sound information.</td></tr>
+  <tr><td>EFX</td><td>Testing.</td></tr>
+  <tr><td>Fredrik Olson</td><td>NES four-player adapter information.</td></tr>
+  <tr><td>goroh</td><td>Various documents.</td></tr>
+  <tr><td>Jeremy Chadwick</td><td>General NES information.</td></tr>
+  <tr><td>kevtris</td><td>Low-level NES information and sound information.</td></tr>
+  <tr><td>Ki</td><td>Various technical information.</td></tr>
+  <tr><td>Mark Knibbs</td><td>Various NES information.</td></tr>
+  <tr><td>Marat Fayzullin</td><td>General NES information.</td></tr>
+  <tr><td>Matthew Conte</td><td>Sound information.</td></tr>
+  <tr><td>nori</td><td>FDS sound information.</td></tr>
+  <tr><td>rahga</td><td>Famicom four-player adapter information.</td></tr>
+  <tr><td>TheRedEye</td><td>ROM images, testing.</td></tr>
+  <tr><th colspan="2" align="right">...and everyone whose name my mind has misplaced.</th></tr>
+ </table>
+ </p>
+ <?php EndSection(); ?>
+
 <?php EndPage(); ?>
 
